/* ----------------------------------------------------------- */
/*                                                             */
/*      Application Example using the ATK Real-Time API        */
/*                                                             */
/*       Machine Intelligence Laboratory (Speech Group)        */
/*        Cambridge University Engineering Department          */
/*                  http://mi.eng.cam.ac.uk/                   */
/*                                                             */
/*               Copyright Steve Young 2000-2003               */
/*                                                             */
/*   Use of this software is governed by a License Agreement   */
/*    ** See the file License for the Conditions of Use  **    */
/*    **     This banner notice must not be removed      **    */
/*                                                             */
/* ----------------------------------------------------------- */
/*                      edited by kxl                          */
/* ----------------------------------------------------------- */



static const char * version="!HVER!parsed_by_kxl_parser:   0.01alfa RC2";

#include "AMonitor.h"
#include "ASource.h"
#include "ACode.h"
#include "ARec.h"
#include "shellapi.h"

#include <iostream>

#include <ctime>
#include <cstdlib>
// ---------------- Globals To Define the Recognition System -----------------

// Information Channels (plumbing)
ABuffer *auChan;   // carries audio from source to Coder
ABuffer *feChan;   // carries feat vecs from Coder to Recogniser
ABuffer *ansChan;  // carries answers from Rec back to Application
// Active components (threads)
ASource *ain;      // audio source
ACode *acode;      // coder
ARec *arec;      // viterbi recogniser
AMonitor *amon;    // system monitor
// Global resources
ARMan *rman;       // resource manager for dict, grammars and HMMSet
AHmms *hset;       // HMM set is global since it never changes
ADict *dict;       // ditto dictionary (though it can be edited if desired)
AGram *ggrm;       // global grammar, always active

SHELLEXECUTEINFO ShExecInfo={0};

void myReplace(string &temp2, string toFind, string replaceWith){
	int pos;
    while ((pos = temp2.find(toFind)) != string::npos)
          temp2.replace(pos,toFind.size(),replaceWith);
}

// output a prompt (just a text string for this simple demo )
void Talk(string s)
{
	string temp2(s);
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");
	myReplace(temp2,"","");

	
	printf("\n%s\n",temp2.c_str());	
		
	temp2 = "Program \"" + temp2 + "\"";
	ShExecInfo.cbSize = sizeof(SHELLEXECUTEINFO);
	ShExecInfo.fMask = SEE_MASK_NOCLOSEPROCESS;
	ShExecInfo.hwnd = NULL;
	ShExecInfo.lpVerb = NULL;
	ShExecInfo.lpFile = "java";		
	ShExecInfo.lpParameters = temp2.c_str();	
	ShExecInfo.lpDirectory = NULL;
	ShExecInfo.nShow = SW_SHOW;
	ShExecInfo.hInstApp = NULL;	
	ShellExecuteEx(&ShExecInfo);	
	WaitForSingleObject(ShExecInfo.hProcess,INFINITE);	
}


typedef enum { unknown, unconfirmed, grounded, cancelled } SlotStatus;
static const float minconf = 0.5;

class QA {
public:
	QA(const string& aname,			// name of qa object
		const string& aprompt,		// query prompt
		const string& gramfile,		// name of grammar file
		const string& ahelp,        // help message
		string** asublattice,
		QA** anextQA,
		const int& aqaCount);		
	QA(const string& aprompt);		// query prompt

	void Listen(string rgroup);	// listen using given res group and update slot value
	void Ask();							// ask question, record answer and set status
	void Check();						// check answer and set status
	void GetSlot();               // get a value for the slot by asking and checking
	void Show();						// show current slot status
	void Reset();
	bool fSublattice();
	SlotStatus status;				// slot status
	string  value;						// slot value
	float  curconf;					// current input
	string curtag;
	string curwords;
private:
	//----------my addd-------kxl----------------------------
	string **sublattice;           //podgramatyki
	QA **nextQA;                   //odpowiedzi na pytania
	int qaCount;                  //ilosc podgramatyk (i jednoczesnie odpowiedzi)
	int foundSublattice;					//znaleziona gramatyka

	string name;                  // name of slot (also name of semantic tag)
	string prompt;						// question
	string help;						// help string
	ResourceGroup *ask;
	ResourceGroup *chk;
};

// construct a QA object with given prompt and grammar
QA::QA(const string& aname, const string& aprompt, 
       const string& gramfile, const string& ahelp, 
	   string** asublattice, QA** anextQA, const int& aqaCount)
{
	// save the prompts
	prompt = aprompt; help = ahelp; name = aname;
	sublattice = asublattice; nextQA = anextQA; qaCount = aqaCount;
	// create grammar specific to this question
	AGram *g1 = new AGram(name,gramfile);
	rman->StoreGram(g1);
	ask = rman->NewGroup(name+"-ask");
	ask->AddHMMs(hset);  // Add the global resources
	ask->AddDict(dict);
	ask->AddGram(ggrm);  // include global grammar in parallel with 
	ask->AddGram(g1);     // qa specific grammar
	// create copy of ask but prepend "No" to front of qa grammar
	// and add confirm in parallel
	chk = rman->NewGroup(name+"-chk");
	chk->AddHMMs(hset);  // Add the global resources
	chk->AddDict(dict);
	chk->AddGram(ggrm);  // include global grammar in parallel with 
	AGram *g2 = new AGram(*g1);    // copy g1
	rman->StoreGram(g2);
	g2->OpenEdit();
	GramSubN *s = g2->main;        // prepend "NO" to front with skip to end
	GramNode *ent = s->NewNullNode(99);
	GramNode *no = s->NewWordNode("NO","no");
	GramNode *yes =s->NewCallNode("confirm","yes");
	s->AddLink(ent,no); s->AddLink(ent,yes); s->AddLink(yes,s->exit);
	s->AddLink(no,s->entry); s->AddLink(no,s->exit); 
	s->entry = ent;
	g2->CloseEdit();
	chk->AddGram(g2);    // Add the new "correction" grammar
	// initial status is unknown
	status = unknown; value = ""; foundSublattice = -1;
}
//only for displaying answer
QA::QA(const string& aprompt){
	prompt = aprompt;
	status = unknown; value = "_null_";
	foundSublattice = 0;
}

// Reset slot values for a new dialogue
void QA::Reset(){
	status = unknown; value = "";
}

// listen to rec packets and construct slot value
void QA::Listen(string rgroup)
{
	APacket p;
	APhraseData *pd;
	string s="";
	float conf=0.0;
	int numwords=0;
	
	curtag=""; curwords="";
	// set the resource group to use and start recognising
	arec->SendMessage("usegrp("+rgroup+")");
	arec->SendMessage("start()");
	// listen to response of form  "tag(w1 w2 ...)"
	do {
      p = ansChan->GetPacket();
		pd = (APhraseData *)p.GetData();
      if (pd->ptype == OpenTag_PT){
			assert(s == "" && numwords == 0);
			do {
				p = ansChan->GetPacket(); pd = (APhraseData *)p.GetData();
				if (pd->ptype == Word_PT) {
					if (s=="") s = pd->word; else s = s + " " + pd->word;
					// printf("{%[0.00]}",pd->word.c_str(),pd->confidence);
					conf += pd->confidence; ++numwords;
				}
			}while(pd->ptype != CloseTag_PT && pd->ptype != End_PT);
			curtag = pd->tag;
			curwords = s;
      }
	} while (pd->ptype != End_PT);
	arec->SendMessage("stop()");
	curconf = numwords==0?0.0:conf/numwords;
}

// ask for information
void QA::Ask(){
	bool ok = false;

	do {
		Talk(prompt);
		Listen(ask->gname);
		ok = fSublattice();
		if(ok!=true){
			if (curtag == "command") {
				if (curwords == "HELP") {
					Talk(help);
				}else if (curwords == "CANCEL"){
					ok = true; status = cancelled;
				}
			}
		}
	} while (!ok);
}
//znajduje do ktorej gramatyki nalezy powiedziane zdanie;
bool QA::fSublattice(){
	bool ret = false;
	
	for(int i = 0; i < qaCount; i++){
		if(curtag == *sublattice[i]){
			if (curconf > minconf){
				status = grounded;
			}else{
				status = unconfirmed;
			}			
			value = curtag;
			ret = true;
			foundSublattice = i;
			i = qaCount;
		}else{
			if(*sublattice[i]=="_noMatter_"){
				status = grounded;
				foundSublattice = i;
				i = qaCount;
				ret = true;
			}
		}
	}
	return ret;
}

// confirm current slot value
void QA::Check(){
	bool ok = false;
	do {
		Talk(">>>>D E B U G I N G<<<<< rozpoznane zdanie to<"+curwords+">");
		Listen(chk->gname);
		if (curtag == "command") {
			if (curwords == "HELP") {
				Talk("Masz potwiedzi czy dobrze Cie zrozumiaam");
			}else if (curwords == "CANCEL"){
				ok = true; status = cancelled;
			}
		}else if (curtag == "yes"){
			ok = true; status = grounded;
		}else if(curtag == "no"){
			ok = true; status = unknown;
		}else ok = fSublattice();
	} while (!ok);
}

void QA::GetSlot()
{
	if(value!="_null_"){
		do {
			Ask();
			while (status == unconfirmed) Check();
		}while (status != grounded && status != cancelled);
		if(status == grounded){
			nextQA[foundSublattice]->GetSlot();
		}else{
			Talk("Jak chcesz..to nie rozmawiam z tob..nastepnym razem lepiej si zastanw!");
		}
	}else{
		Talk(prompt);
	}
}


// ---------------------- Initialisation Code ---------------------------

void Initialise(int argc, char *argv[])
{
  if (InitHTK(argc,argv,version)<SUCCESS){
    HRError(9999,"SSDS: cannot initialise HTK\n");
    throw HTK_Error(9999);
  }
  cout << "\t 25th Logical Science Department "<<endl;
  Sleep(1000);
  cout << "\t\t praudly present "<<endl;
  Sleep(1000);
  cout << "\t    psycho fun with ASR" << endl;  
}

void BuildRecogniser()
{	
  // create some plumbing
  auChan = new ABuffer("auChan");
  feChan = new ABuffer("feChan");
  ansChan = new ABuffer("ansChan");
  // create a resource manager
  rman = new ARMan;
  // create active components linked by buffers
  ain = new ASource("AIn",auChan);
  acode = new ACode("ACode",auChan,feChan);
  arec = new ARec("ARec",feChan,ansChan,rman);
  // create global fixed resources
  hset = new AHmms("HmmSet"); // load info in config
  AObsData *od = acode->GetSpecimen();
  if (!hset->CheckCompatible(&(od->data))){
     HRError(9999,"SSDS: HMM set is not compatible with Coder"); 
     throw ATK_Error(9999);
  }     
  dict = new ADict("ADict");  // load info in config   
  ggrm = new AGram("GGram", "p_wstep.net");  
  rman->StoreHMMs(hset);
  rman->StoreDict(dict);
  rman->StoreGram(ggrm);
  // finally create Monitor
  amon = new AMonitor;
  amon->AddComponent(ain);   //register components
  amon->AddComponent(acode); //with the monitor
  amon->AddComponent(arec);
}

void StartRecogniser()
{
  // Start up each component thread
  amon->Start();
  ain->Start(); 
  // uncomment following if completely hands-free
  // ain->SendMessage("start()");
  acode->Start();
  arec->Start();  
  // note recogniser will not actually do anything until it
  // receives a "start" command
}

void ShutDown()
{
  // ask all threads to terminate
  ain->SendMessage("terminate()");
  acode->SendMessage("terminate()");
  arec->SendMessage("terminate()");
  // wait till they actually do it
  ain->Join(); acode->Join();  arec->Join();
  HJoinMonitor();
}

// ------------------------- Application Code ---------------------------

void RunApplication()
{
	string *n1aS = new string("negacja");
	QA *n1aQ = new QA("Miczak!");
	string *n2aS = new string("psychika");
	QA *n2aQ = new QA("A wic wybrae psychik.");
	string *n2bS = new string("orientacja");
	QA *n2bQ = new QA("A wic wybrae orientacj.");
	string *n2cS = new string("inteligencja");
	QA *n2cQ = new QA("A wic wybrae inteligencj.");
	string *n1bS = new string("akceptacja");
	string *n1bSS[3]={
		n2aS,
		n2bS,
		n2cS
		};
	QA *n1bSQ[3]={
		n2aQ,
		n2bQ,
		n2cQ
		};
	QA *n1bQ = new QA(
		"n1b",
		"Wic jeste odwan osob moe si czego o sobie dowiesz jaki rodzaj tecikw ci interesuje? Moemy przetestowa twoj inteligencj, orientacj lub psychik. Co wybierasz?",
		"p_rodzaj_testu.net",
		"",
		n1bSS,
		n1bSQ,
		3);
	string *n1SS[2]={
		n1aS,
		n1bS
		};
	QA *n1SQ[2]={
		n1aQ,
		n1bQ
		};
	QA *n1Q = new QA(
		"n1",
		"Witamy w naszej interaktywnej psychozabawie. Czy czujesz si na siach podj to wyzwanie?",
		"p_wstep.net",
		"",
		n1SS,
		n1SQ,
		2);

	StartRecogniser();
	n1Q->GetSlot();
	if(n1bQ->curtag == "psychika")
	{
		string *n3aS = new string("akceptacja");
		QA *n3aQ = new QA("C wasnie zabie Beethovena.");
		string *n3bS = new string("negacja");
		QA *n3bQ = new QA("No prosze, ocalie Beethovena.");
		string *n3SS[2]={
		n3aS,
		n3bS
		};
		QA *n3SQ[2]={
		n3aQ,
		n3bQ
		};
		QA *n3Q = new QA(
		"n3",
		"Wic zaczynamy. Gdyby zna kobiet, ktra ma ju omioro dzieci, z czego dwoje jest guchych, dwoje jest lepych a jedno upoledzone umysowo, przy czym owa kobieta jest chora na syfilis, to czy zalecaby (zalecaaby) aborcj?",
		"p1.net",
		"",
		n3SS,
		n3SQ,
		2);

		
		n3Q->GetSlot();

		string *n4aS = new string("a");
		QA *n4aQ = new QA("Twj kandydat to Franklin D. Roosevelt.");
		string *n4bS = new string("b");
		QA *n4bQ = new QA("Twj kandydat to Winston Churchill.");
		string *n4cS = new string("c");
		QA *n4cQ = new QA("Brawo twj kandydat to Adolf Hitler lepiej odpu sobie wybory w tym roku.");
		string *n4SS[3]={
		n4aS,
		n4bS,
		n4cS
		};
		QA *n4SQ[3]={
		n4aQ,
		n4bQ,
		n4cQ
		};
		QA *n4Q = new QA(
		"n4",
		"Wybierasz przywdc dla caego wiata. Jest trzech kandydatw. Kandydat A. Konsultuje si z astrologiem, ma powizania ze skorumpowanymi politykami, ma dwie kochanki, naogowo pali i wypija 8 do 10 martini dziennie. Kandydat Be. Zosta wyrzucony ze stanowiska dwukrotnie, pi do poudnia, uywa opium w szkole i wypija wiartk whisky kadego wieczora. Kandydat Ce. Odznaczony bohater wojenny. Wegetarianin, nie pali, czasem pije piwo, jest monogamist. Ktrego kandydata wybierasz?",
		"p2.net",
		"",
		n4SS,
		n4SQ,
		3);

		
		n4Q->GetSlot();

		string *n5cS = new string("akceptacja");
		QA *n5cQ = new QA("Odpowied prawidowa, co znaczy e rozumujesz jak psychopata....!!!!! Ten test zosta stworzony przez synnego amerykaskiego psychologa i pozwala weryfikowa potencjalnych zabojcw. Wielu seryjnych mordercw odpowiedziao prawidowo na to pytanie. Pomyl nad tym!");
		string *n5dS = new string("negacja");
		QA *n5dQ = new QA("Odpowied bedna. Lepiej dla Ciebie. Ten test zosta stworzony przez synnego amerykaskiego psychologa i pozwala weryfikowa potencjalnych zabojcw. Wielu seryjnych mordercw odpowiedziao prawidowo na to pytanie.");
		string *n5aS = new string("akceptacja");
		string *n5aSS[2]={
		n5cS,
		n5dS
		};
		QA *n5aSQ[2]={
		n5cQ,
		n5dQ
		};
		QA *n5aQ = new QA(
		"n5a",
		"Czy chcesz przez to powiedzie e powodem bya nadzieja i chopak w ktrym si zakochaa znw pojawi si na pogrzebie?",
		"p3_pomocnicze.net",
		"",
		n5aSS,
		n5aSQ,
		2);
		string *n5SS[1]={
		n5aS
		};
		QA *n5SQ[1]={
		n5aQ
		};
		QA *n5Q = new QA(
		"n5",
		"Historia pewnej dziewczyny. Na pogrzebie swojej matki spotyka chopaka ktrego wczeniej nigdy nie widziaa. Nieoczekwianie dostrzega w nim mczyzne swego ycia i w tym samym dniu zakochuje si od pierwszego wejrzenia... Kilka dni pniej dziewczyna zabija swoj siostr. Jaki jest powd zabicia wasnej siostry?",
		"p3.net",
		"",
		n5SS,
		n5SQ,
		1);

		
		n5Q->GetSlot();	
	}
	else if(n1bQ->curtag == "orientacja")
	{
		cout << "Ile to jest???" << endl;
		cout << "2 + 2" << endl;
		Sleep(1000);
		cout << "4 + 4" << endl;
		Sleep(1000);
		cout << "8 + 8" << endl;
		Sleep(1000);
		cout << "16 + 16" << endl;
		Sleep(1000);	
		string *n7aS = new string("akceptacja");
		QA *n7aQ = new QA("A 98 procent populacji redniakw w tym wiczeniu myli o sidemce. Straszne, nie?");
		string *n7bS = new string("negacja");
		QA *n7bQ = new QA("Naleysz do 2 procent ludzi na wiecie, ktrych umysy s na tyle plastyczne, e sta ich na wymylenie czego oryginalnego. 98 procent populacji redniakw myli w tym wiczeniu o 7.");
		string *n7SS[2]={
		n7aS,
		n7bS
		};
		QA *n7SQ[2]={
		n7aQ,
		n7bQ
		};
		QA *n7Q = new QA(
		"n7",
		"No to jedziemy. Szybko pomyl i powiedz jak liczb pomiedzy 5 a 12.",
		"p4.net",
		"",
		n7SS,
		n7SQ,
		2);
		n7Q->GetSlot();

		cout<<"Sprbujmy czego podobnego. Odpowiadaj bardzo szybko."<<endl;

		cout<<"Jakiego koloru jest nieg?"<<endl;
		Sleep(1000);

		cout<<"Jakiego koloru s chmurki na niebie?"<<endl;
		Sleep(1000);

		cout<<"Jakiego koloru s zazwyczaj firanki?"<<endl;
		Sleep(1000);

		cout<<"Jakiego koloru jest zazwyczaj pociel?"<<endl;
		Sleep(1000);

		cout<<"Jakiego koloru jest typowa szkolna kreda?"<<endl;
		Sleep(1000);

		cout<<"Jakiego koloru jest przewanie papier?"<<endl;
		Sleep(1000);

		cout<<"Na jaki kolor maluje si przewanie sufit?"<<endl;
		Sleep(1000);

		string *n8aS = new string("mleko");
		QA *n8aQ = new QA("Zapewniam: krowa nie pije mleka tylko wod.");
		string *n8bS = new string("woda");
		QA *n8bQ = new QA("Brawo!  Tym razem nie dae si nabra. Ciko by jej byo pi wasne mleko.");
		string *n8SS[2]={
		n8aS,
		n8bS
		};
		QA *n8SQ[2]={
		n8aQ,
		n8bQ
		};
		QA *n8Q = new QA(
		"n8",
		"Co pije krowa?",
		"p5.net",
		"",
		n8SS,
		n8SQ,
		2);

		
		n8Q->GetSlot();
		cout << "Sprbuj teraz wykona taki test. Naprawd nie jest trudny. Musisz tylko kolejno odpowiada na pytania tak szybko, jak potrafisz. Nie zapisuj odpowiedzi na kartce - wykonuj je w mysli."<< endl;
		cout << "Ile to jest?" <<endl;

		cout << "15+6?" <<endl;
		Sleep(1000);
		cout << "3+56?" <<endl;
		Sleep(1000);
		cout << "89+2?" <<endl;
		Sleep(1000);
		cout << "12+53?" <<endl;
		Sleep(1000);
		cout << "75+26?" <<endl;
		Sleep(1000);
		cout << "25+52?" <<endl;
		Sleep(1000);
		cout << "63+32?" <<endl;
		Sleep(1000);
		cout << "123+5?" <<endl;
		Sleep(1000);

		string *n9cS = new string("akceptacja");
		QA *n9cQ = new QA("98 procent ludzi podczas tego wiczenia przychodzi na myl motek.");
		string *n9dS = new string("negacja");
		QA *n9dQ = new QA("Naleysz wic do tych 2 procent ludzi, ktrzy MYL INACZEJ, albo nawet nienormalnie. 98 procent ludzi podczas tego wiczenia przychodzi na myl motek.");
		string *n9aS = new string("dalej");
		string *n9aSS[2]={
		n9cS,
		n9dS
		};
		QA *n9aSQ[2]={
		n9cQ,
		n9dQ
		};
		QA *n9aQ = new QA(
		"n9a",
		"Wasnie pomylae o motku, prawda?",
		"p6.net",
		"",
		n9aSS,
		n9aSQ,
		2);
		string *n9SS[1]={
		n9aS
		};
		QA *n9SQ[1]={
		n9aQ
		};
		QA *n9Q = new QA(
		"n9",
		"A teraz szybko pomyl o jakims narzdziu. Jak ju bdziesz mie jakie narzdzie na myli powiedz DALEJ.",
		"p6_poczatek.net",
		"",
		n9SS,
		n9SQ,
		1);		
		n9Q->GetSlot();
	}
	else if(n1bQ->curtag == "inteligencja")
	{
		string *n10aS = new string("akceptacja");
		QA *n10aQ = new QA("Dobrze.");
		string *n10bS = new string("negacja");
		QA *n10bQ = new QA("Nie, nie, nie i jeszcze raz nie. Odpowied to 1 godzina.");
		string *n10SS[2]={
		n10aS,
		n10bS
		};
		QA *n10SQ[2]={
		n10aQ,
		n10bQ
		};
		QA *n10Q = new QA(
		"n10",
		"Idziesz spa o smej, wstajesz o dziewitej rano. Ile godzin spae?",
		"p7.net",
		"",
		n10SS,
		n10SQ,
		2);
		
		n10Q->GetSlot();

		string *n11aS = new string("akceptacja");
		QA *n11aQ = new QA("Dobra odpowied brawo.");
		string *n11bS = new string("negacja");
		QA *n11bQ = new QA("le ale to byo podchwytliwe. A bdzie takich pyta wicej.");
		string *n11SS[2]={
		n11aS,
		n11bS
		};
		QA *n11SQ[2]={
		n11aQ,
		n11bQ
		};
		QA *n11Q = new QA(
		"n11",
		"W jaki sposb witaj si papieze?",
		"p8.net",
		"",
		n11SS,
		n11SQ,
		2);
		
		n11Q->GetSlot();

		string *n12aS = new string("akceptacja");
		QA *n12aQ = new QA("Dobrze, pogratulowa czujnoci.");
		string *n12bS = new string("negacja");
		QA *n12bQ = new QA("Abel nie mia arki.");
		string *n12SS[2]={
		n12aS,
		n12bS
		};
		QA *n12SQ[2]={
		n12aQ,
		n12bQ
		};
		QA *n12Q = new QA(
		"n12",
		"Ile zwierzat Abel zabra na Ark?",
		"p9.net",
		"",
		n12SS,
		n12SQ,
		2);
		
		n12Q->GetSlot();

		string *n13aS = new string("akceptacja");
		QA *n13aQ = new QA("Oczywicie.");
		string *n13bS = new string("negacja");
		QA *n13bQ = new QA("Nie, pomaraczowa.");
		string *n13SS[2]={
		n13aS,
		n13bS
		};
		QA *n13SQ[2]={
		n13aQ,
		n13bQ
		};
		QA *n13Q = new QA(
		"n13",
		"Jakiego koloru jest czarna skrzynka w samolocie?",
		"p10.net",
		"",
		n13SS,
		n13SQ,
		2);
		
		n13Q->GetSlot();

		string *n14aS = new string("akceptacja");
		QA *n14aQ = new QA("Bardzo dobrze w kocu to Kain zabi Abla.");
		string *n14bS = new string("negacja");
		QA *n14bQ = new QA("Nikt. Kain zabi Abla.");
		string *n14SS[2]={
		n14aS,
		n14bS
		};
		QA *n14SQ[2]={
		n14aQ,
		n14bQ
		};
		QA *n14Q = new QA(
		"n14",
		"Kto zabi Kaina?",
		"p11.net",
		"",
		n14SS,
		n14SQ,
		2);
		
		n14Q->GetSlot();

		string *n15aS = new string("akceptacja");
		QA *n15aQ = new QA("Brawo.");
		string *n15bS = new string("negacja");
		QA *n15bQ = new QA("Poprawna odpowied to zapak lub zapalniczk.");
		string *n15SS[2]={
		n15aS,
		n15bS
		};
		QA *n15SQ[2]={
		n15aQ,
		n15bQ
		};
		QA *n15Q = new QA(
		"n15",
		"W pokoju stoi lampa naftowa i wieca. Co najpierw zapalisz?",
		"p12.net",
		"",
		n15SS,
		n15SQ,
		2);
		
		n15Q->GetSlot();

		string *n16aS = new string("akceptacja");
		QA *n16aQ = new QA("Masz racje to poprawna odpowied.");
		string *n16bS = new string("negacja");
		QA *n16bQ = new QA("Pierwsi na ziemi to byli Adam i Ewa.");
		string *n16SS[2]={
		n16aS,
		n16bS
		};
		QA *n16SQ[2]={
		n16aQ,
		n16bQ
		};
		QA *n16Q = new QA(
		"n16",
		"Z samolotu wyskoczyo 3 skoczkw: Pierwszy way 80 kilogramw, drgi 100 kilogramw, trzeci 60 kilogramw. Kto by pierwszy na Ziemi?",
		"p13.net",
		"",
		n16SS,
		n16SQ,
		2);
		
		n16Q->GetSlot();

		string *n17aS = new string("akceptacja");
		QA *n17aQ = new QA("Dobrze.");
		string *n17bS = new string("negacja");
		QA *n17bQ = new QA("le, w morzu najwicej jest mokrych kamieni.");
		string *n17SS[2]={
		n17aS,
		n17bS
		};
		QA *n17SQ[2]={
		n17aQ,
		n17bQ
		};
		QA *n17Q = new QA(
		"n17",
		"Jakich kamieni jest w morzu najwicej?",
		"p14.net",
		"",
		n17SS,
		n17SQ,
		2);
		
		n17Q->GetSlot();

		string *n18aS = new string("akceptacja");
		QA *n18aQ = new QA("Dobrze rozumujesz, to dobra odpowied.");
		string *n18bS = new string("negacja");
		QA *n18bQ = new QA("Zostao siedem zastrzelonych, reszta ucieka.");
		string *n18SS[2]={
		n18aS,
		n18bS
		};
		QA *n18SQ[2]={
		n18aQ,
		n18bQ
		};
		QA *n18Q = new QA(
		"n18",
		"Na pocie siedzi 10 wron. Myliwi zastrzelili 7 reszta ucieka, ile zostao?",
		"p15.net",
		"",
		n18SS,
		n18SQ,
		2);
		
		n18Q->GetSlot();

		string *n19aS = new string("akceptacja");
		QA *n19aQ = new QA("Oczywicie mwimy ustami. Oczywicie nie dotyczy to niemowy.");
		string *n19bS = new string("negacja");
		QA *n19bQ = new QA("Skoro odpowiadasz na pytania to raczej mwisz ustami. Rkoma to tylko niemowa by si dogada ale niestety nie z tym programem.");
		string *n19SS[2]={
		n19aS,
		n19bS
		};
		QA *n19SQ[2]={
		n19aQ,
		n19bQ
		};
		QA *n19Q = new QA(
		"n19",
		"Teraz zostawmy wrony w spokoju i przejdmy do kolejnego pytania. Czym sie mwi: rkami czy rkoma?",
		"p16.net",
		"",
		n19SS,
		n19SQ,
		2);
		
		n19Q->GetSlot();

		string *n20aS = new string("akceptacja");
		QA *n20aQ = new QA("Masz racj, wikszo dzieci rodzi si w dziewitym miesicu.");
		string *n20bS = new string("negacja");
		QA *n20bQ = new QA("Za odpowied. Wikszo dzieci rodzi si w dziewitym miesicu.");
		string *n20SS[2]={
		n20aS,
		n20bS
		};
		QA *n20SQ[2]={
		n20aQ,
		n20bQ
		};
		QA *n20Q = new QA(
		"n20",
		"W ktrym miesicu rodzi si najwicej dzieci?",
		"p17.net",
		"",
		n20SS,
		n20SQ,
		2);
		
		n20Q->GetSlot();

		string *n21aS = new string("akceptacja");
		QA *n21aQ = new QA("Tak usiad wtedy na tronie.");
		string *n21bS = new string("negacja");
		QA *n21bQ = new QA("Nie. Usiad.");
		string *n21SS[2]={
		n21aS,
		n21bS
		};
		QA *n21SQ[2]={
		n21aQ,
		n21bQ
		};
		QA *n21Q = new QA(
		"n21",
		"To teraz co z historii. Co zrobi Sobieski po wstpieniu na tron?",
		"p18.net",
		"",
		n21SS,
		n21SQ,
		2);
		
		n21Q->GetSlot();

		string *n22aS = new string("akceptacja");
		QA *n22aQ = new QA("Poprawnie.");
		string *n22bS = new string("negacja");
		QA *n22bQ = new QA("Niestety nie. W obu przypadkach 12.");
		string *n22SS[2]={
		n22aS,
		n22bS
		};
		QA *n22SQ[2]={
		n22aQ,
		n22bQ
		};
		QA *n22Q = new QA(
		"n22",
		"Ile tuzin ma zotwek, a ile pidziesicio zotwek?",
		"p19.net",
		"",
		n22SS,
		n22SQ,
		2);
		
		n22Q->GetSlot();

		string *n23aS = new string("akceptacja");
		QA *n23aQ = new QA("Tak wanie o t odpowied chodzio.");
		string *n23bS = new string("negacja");
		QA *n23bQ = new QA("Ostatnie pojawiaj si sztuczne eby.");
		string *n23SS[2]={
		n23aS,
		n23bS
		};
		QA *n23SQ[2]={
		n23aQ,
		n23bQ
		};
		QA *n23Q = new QA(
		"n23",
		"Jakie zby pojawiaj si u ludzi najpniej?",
		"p20.net",
		"",
		n23SS,
		n23SQ,
		2);
		
		n23Q->GetSlot();

		string *n24aS = new string("akceptacja");
		QA *n24aQ = new QA("Brawo poprawna odpowied.");
		string *n24bS = new string("negacja");
		QA *n24bQ = new QA("Te ale kady miesic ma rwniez przynajmniej 28 dni.");
		string *n24SS[2]={
		n24aS,
		n24bS
		};
		QA *n24SQ[2]={
		n24aQ,
		n24bQ
		};
		QA *n24Q = new QA(
		"n24",
		"Ktry miesic ma 28 dni?",
		"p21.net",
		"",
		n24SS,
		n24SQ,
		2);
		
		n24Q->GetSlot();		

		string *n26aS = new string("akceptacja");
		QA *n26aQ = new QA("Gratulacje byo ich pi.");
		string *n26bS = new string("negacja");
		QA *n26bQ = new QA("Niestety byo pi przystankw.");
		string *n26SS[2]={
		n26aS,
		n26bS
		};
		QA *n26SQ[2]={
		n26aQ,
		n26bQ
		};
		QA *n26Q = new QA(
		"n26",
		"W autobusie jechao 70 osb (krtki Ikarus, jedcy dwa razy dziennie) je, na pierwszym przystanku wysiady 4. Na drugim wysiado 20 i wsiado 15. Na kolejnym przystanku wsiado 7 osb. Na kolejnym przystanku wysiado 12 a wsiady 3, na ostatnim wsiado 15 a wysiady 4 osoby. Ile byo przystankw?",
		"p22.net",
		"",
		n26SS,
		n26SQ,
		2);
		
		n26Q->GetSlot();

	}
	srand(static_cast<unsigned>(time(0)));
	int random_int = rand();
	cout << "Twoj wynik to: "<<endl;
	cout << random_int << endl;
	cout<< "GRATULUJEMY!!!"<<endl;
	cout << "Skala:: "<<endl;
	cout << "13 - 16pkt geniusz"<<endl;
	cout << "10 - 12pkt inteligentny"<<endl;
	cout << "6  - 9pkt pinteligentny"<<endl;
	cout << "3  - 5pkt jednostka nie nadajca si do samodzielnego mylenia"<<endl;
	cout << "0  - 2pkt bez obrazy ale wg wyniku testu moge powiedziec tylko jedno: absolutny kretyn"<<endl;

	// Start recogniser running

	printf("\n\n================BYE==================\n\n");
}

// --------------------------- Main Program ----------------------------

int main(int argc, char *argv[])
{
  try {
    Initialise(argc,argv);
	cout << "po init" <<endl;
    BuildRecogniser();
	cout << " po build"<<endl;
    RunApplication();
  }
  catch (ATK_Error e){
	  cout << e.i << endl;
  }
  catch (HTK_Error e){
	  cout << e.i << endl;
  }
  return 0;
}

// ------------------------- End KxL -----------------------------

